@@ -1,7 +1,7 @@
 package Getopt::Long::EvenLess;
 
-our $DATE = '2015-06-17'; # DATE
-our $VERSION = '0.03'; # VERSION
+our $DATE = '2015-06-19'; # DATE
+our $VERSION = '0.04'; # VERSION
 
 use 5.010001;
 use strict 'subs', 'vars';
@@ -33,7 +33,7 @@ sub GetOptionsFromArray {
     my %spec_by_opt_name;
     for (keys %spec) {
         my $orig = $_;
-        s/=s\z//;
+        s/=[fios]\@?\z//;
         s/\|.+//;
         $spec_by_opt_name{$_} = $orig;
     }
@@ -43,7 +43,7 @@ sub GetOptionsFromArray {
         my @candidates;
       OPT_SPEC:
         for my $spec (keys %spec) {
-            $spec =~ s/=s\z//;
+            $spec =~ s/=[fios]\@?\z//;
             my @opts = split /\|/, $spec;
             for my $o (@opts) {
                 next if $short_mode && length($o) > 1;
@@ -94,7 +94,7 @@ sub GetOptionsFromArray {
             my ($used_name, $val_in_opt) = ($1, $2);
             my $opt = $code_find_opt->($used_name);
             if (!defined($opt)) {
-                push @remaining, $argv->[$i] unless defined($opt);
+                push @remaining, $argv->[$i];
                 next ELEM;
             } elsif (!length($opt)) {
                 next ELEM; # ambiguous
@@ -102,7 +102,7 @@ sub GetOptionsFromArray {
 
             my $spec = $spec_by_opt_name{$opt};
             # check whether option requires an argument
-            if ($spec =~ /=s\z/) {
+            if ($spec =~ /=[fios]\@?\z/) {
                 if (defined $val_in_opt) {
                     # argument is taken after =
                     if (length $val_in_opt) {
@@ -137,7 +137,7 @@ sub GetOptionsFromArray {
 
                 my $spec = $spec_by_opt_name{$opt};
                 # check whether option requires an argument
-                if ($spec =~ /=s\z/) {
+                if ($spec =~ /=[fios]\@?\z/) {
                     if (length $str) {
                         # argument is taken from $str
                         $code_set_val->($opt, $str);
@@ -190,7 +190,7 @@ Getopt::Long::EvenLess - Like Getopt::Long::Less, but with even less features
 
 =head1 VERSION
 
-This document describes version 0.03 of Getopt::Long::EvenLess (from Perl distribution Getopt-Long-EvenLess), released on 2015-06-17.
+This document describes version 0.04 of Getopt::Long::EvenLess (from Perl distribution Getopt-Long-EvenLess), released on 2015-06-19.
 
 =head1 DESCRIPTION
 
@@ -214,9 +214,7 @@ Nothing to configure, no different modes of operation.
 
 =item * does not support increment (C<foo+>)
 
-=item * does not support types (only strings are supported)
-
-No type checking
+=item * no type checking (C<foo=i>, C<foo=f>, C<foo=s> all accept any string)
 
 =item * does not support optional value (C<foo:s>), only no value (C<foo>) or required value (C<foo=s>)
 
@@ -235,23 +233,23 @@ object as its first argument.
 
 Sample startup overhead benchmark:
 
-                            Rate      run_gl     load_gl load_gl_evenless run_gl_less run_gl_evenless load_gl_less   perl
- run_gl            75.92+-0.34/s          --       -0.3%           -67.6%      -68.0%          -68.2%       -69.1% -88.3%
- load_gl           76.11+-0.26/s 0.25+-0.56%          --           -67.5%      -67.9%          -68.1%       -69.0% -88.3%
- load_gl_evenless   234.2+-1.2/s 208.5+-2.1% 207.8+-1.9%               --       -1.3%           -1.8%        -4.5% -63.8%
- run_gl_less        237.3+-1.1/s   212.6+-2% 211.8+-1.8%      1.31+-0.69%          --           -0.5%        -3.3% -63.4%
- run_gl_evenless  238.57+-0.57/s 214.2+-1.6% 213.5+-1.3%      1.85+-0.57% 0.53+-0.52%              --        -2.8% -63.2%
- load_gl_less         245.4+-1/s   223.2+-2% 222.4+-1.7%      4.75+-0.69% 3.39+-0.64%      2.85+-0.5%           -- -62.1%
- perl                 647.8+-1/s 753.3+-4.1% 751.2+-3.2%      176.6+-1.5%   173+-1.3%   171.55+-0.78%    164+-1.2%     --
+                            Rate     load_gl      run_gl run_gl_less run_gl_evenless load_gl_evenless load_gl_less   perl
+ load_gl            76.8+-0.17/s          --       -0.7%      -50.0%          -64.0%           -67.3%       -69.2% -88.2%
+ run_gl             77.3+-0.18/s 0.66+-0.32%          --      -49.6%          -63.8%           -67.1%       -69.0% -88.1%
+ run_gl_less        153.5+-3.5/s  99.9+-4.5%  98.6+-4.5%          --          -28.1%           -34.7%       -38.4% -76.3%
+ run_gl_evenless      213.5+-2/s   178+-2.7% 176.2+-2.7%  39.1+-3.4%              --            -9.2%       -14.3% -67.1%
+ load_gl_evenless   235.2+-1.1/s 206.2+-1.6% 204.2+-1.6%  53.2+-3.5%      10.2+-1.2%               --        -5.6% -63.7%
+ load_gl_less     249.14+-0.82/s 224.4+-1.3% 222.3+-1.3%  62.3+-3.7%      16.7+-1.2%      5.94+-0.62%           -- -61.6%
+ perl               648.3+-1.9/s   744.2+-3% 738.7+-3.1% 322.4+-9.6%       203.7+-3%      175.7+-1.6%  160.2+-1.1%     --
  
  Average times:
-   perl            :     1.5437ms
-   load_gl_less    :     4.0750ms
-   run_gl_evenless :     4.1916ms
-   run_gl_less     :     4.2141ms
-   load_gl_evenless:     4.2699ms
-   load_gl         :    13.1389ms
-   run_gl          :    13.1718ms
+   perl            :     1.5425ms
+   load_gl_less    :     4.0138ms
+   load_gl_evenless:     4.2517ms
+   run_gl_evenless :     4.6838ms
+   run_gl_less     :     6.5147ms
+   run_gl          :    12.9366ms
+   load_gl         :    13.0208ms
 
 =for Pod::Coverage .+
 
